@@ -3,27 +3,33 @@
 #'
 #' Given the probability distributions \eqn{P\in[0,\,1]^{n\times 3}} of the
 #' dependent variable, it computes the the values of linear predictors
-#' \eqn{XB\in\textbf{R}^{n\times 2}} according to notation used in Santi,
-#' Dickson and Espa (2019).
+#' \eqn{XB\in\textbf{R}^{n\times 2}} according to notation used in
+#' \insertCite{santi2019;textual}{plot3logit}.
 #'
 #' @param P object of class `matrix` (or other coercible classes) such that
 #'   \eqn{P\in[0,\,1]^{n\times 3}}.
 #' @param alpha `numeric` vector of length two where constants \eqn{\alpha^{(1)}}
 #'   and \eqn{\alpha^{(2)}} are stored (only for ordinal models), as
-#'   defined in Equation (7) of Santi, Dickson and Espa (2019).
+#'   defined in Equation (7) of \insertCite{santi2019;textual}{plot3logit}.
+#' @param model object of class `field3logit`.
 #'
 #' @return
 #' Numeric matrix \eqn{\textbf{R}^{n\times 2}} of linear predictors.
 #'
-#' @references Santi F., M. M. Dickson, G. Espa (2019)
-#' "A graphical tool for interpreting regression coefficients of trinomial logit
-#' models", *The American Statistician*, **73**(2), pp. 200-207.
-#' \doi{10.1080/00031305.2018.1442368}
+#' @references
+#' \insertAllCited{}
 #'
 #' @seealso [`XB2P`].
 #'
 #' @name P2XB
-NULL
+P2XB <- function(P, model) {
+  if (model$ordinal) {
+  	out <- P2XB_ord3logit(P)
+  } else {
+  	out <- P2XB_cat3logit(P)
+  }
+  return(out)
+}
 
 
 
