@@ -33,6 +33,33 @@ prepare_block <- function(label, idarrow, comp, from, to, confregion) {
 
 
 
+field3logit_list <- function(model, delta, label, p0, alpha, vcov, nstreams,
+  narrows, edge, conf, npoints) {
+    	
+  delta %>%
+  lapply(function(w) {
+  	if (is.list(w)) {
+  	  list(
+  	    model = model, label = label, p0 = p0, alpha = alpha, 
+  	    vcov = vcov, nstreams = nstreams, narrows = narrows,
+  	    edge = edge, conf = conf, npoints
+  	  ) %>%
+  	  modifyList(w) %>%
+  	  do.call('field3logit', .) -> out
+  	} else {
+  	  field3logit(
+  	    model, w, paste(w, collapse = '|'), p0, alpha, vcov,
+  	    nstreams, narrows, edge, conf, npoints
+  	  ) -> out
+  	}
+  	out
+  }) %>%
+  Reduce(`+`, .) %>%
+  return
+}
+
+
+
 #' `field3logit` simplification function and test
 #'
 #' Given an object of class `field3logit`, [simplify_field3logit()] returns
@@ -74,8 +101,12 @@ is_simplified_field3logit <- function(x) {
 #'
 #' The method [plot()] draws the ternary plot using standard graphics methods
 #' provided by package `Ternary`. See function [gg3logit()] for plotting
-#' through the package [`ggtern`][ggtern::ggtern-package] based on the grammar
-#' of graphics.
+#' through the package [`ggtern`][ggtern::ggtern_package] based on the
+#' grammar of graphics.
+#' 
+#' Methods [as.data.frame()], [as_tibble()], [fortify()] and [tidy()] permits
+#' the graphical information of a `field3logit` object to be exported in a
+#' standardised format (either a `data.frame` or a `tibble`).
 #'
 #' @details
 #'
@@ -93,6 +124,18 @@ is_simplified_field3logit <- function(x) {
 #'
 #' See examples for comparing all three methods.
 #'
+#' **It is also possible to pass a `list` to argument `delta`.** In such a case,
+#' the function `field3logit` is run once for every component of `delta`,
+#' and the set of generated `field3logit` objects is combined into a single
+#' object of class `multifield3logit`. The compoments of the list passed to
+#' `delta` must be named lists whose elements are used as arguments of each call
+#' of function `field3logit`, whereas the arguments specified in the parent call
+#' of `field3logit` are used as default values. It follows that arguments shared
+#' by all fields can be specified once in the parent call of `field3logit`, and
+#' only arguments which changes from field to field (such as `delta` and
+#' `label`) should be set in the lists making up the list passed to `delta`. See
+#' the last example in section Examples and the help of [multifield3logit()].
+#'
 #' @inheritParams effect
 #' @param model either a fitted trinomial model or a matrix of regressor
 #'   coefficients. See section *Compatibility* and examples of
@@ -101,15 +144,17 @@ is_simplified_field3logit <- function(x) {
 #'   This could be either a `numeric` vector, the name of a covariate
 #'   (passed either as a `character` or an `expression`), or a mathematical
 #'   expression involving one or more than one covariates (passed either as
-#'   a `character` or an `expression`). See details and examples.
+#'   a `character` or an `expression`). If a list is passed to `delta`,
+#'   multiple fields are computed according to parameters passed as
+#'   components of a 2-level list. See details and examples.
 #' @param p0 `list` of starting points (ternary coordinates) of the curves
 #'   of the field. If not specified, `field3logit` automatically compute
-#'   `ncurves` candidate points so that arrows are evenly distributed over
+#'   `nstreams` candidate points so that arrows are evenly distributed over
 #'   the ternary plot area. See Examples.
 #' @param alpha `numeric` vector of length two where constants \eqn{\alpha^{(1)}}
 #'   and \eqn{\alpha^{(2)}} are stored (only for ordinal models), as
 #'   defined in Equation (7) of \insertCite{santi2019;textual}{plot3logit}.
-#' @param ncurves number of curves of the field to be computed. In case
+#' @param nstreams number of stream lines of the field to be computed. In case
 #'   of ordinal models, this parameter is ineffective, as only one curve
 #'   can be drawn. The parameter is ineffective also in case that argument
 #'   `p0` is set.
@@ -121,8 +166,9 @@ is_simplified_field3logit <- function(x) {
 #'   should be added to an existing plot (`add = TRUE`) or a new
 #'   ternary plot should be drawn (`add = FALSE`).
 #' @param ... other arguments passed to or from other methods.
-#' @param wide it allows to choose whether `as.data.frme` should return a
-#'   `data.frame` object in wide (default) or long form.
+#' @param wide it allows to choose whether `as.data.frame`, `as_tibble`,
+#'   `fortify` and `tidy` should return a `data.frame` or a `tibble` in wide
+#'   (default) or long form.
 #' @param label label to be used for identifying the field when multiple
 #'   fields are plotted. See [multifield3logit()].
 #' @param data not used. Argument included only for interface compatibility with
@@ -136,9 +182,11 @@ is_simplified_field3logit <- function(x) {
 #'   of the variance-covariance matrix should be ordered according to the matrix 
 #'   of parameter estimates where the categories of the dependent variable are
 #'   the slow index, whereas the covariates are the fast index.
+#' @param value value to be assigned.
 #'
 #' @return
-#' `S3` object of class `field3logit` structured as a named `list`.
+#' `S3` object of class `field3logit` structured as a named `list` or an object
+#' of class `multifield3logit` if `delta` is a `list`.
 #'
 #' @seealso
 #' [multifield3logit()], [gg3logit()], [autoplot()].
@@ -149,10 +197,10 @@ is_simplified_field3logit <- function(x) {
 #' \insertAllCited{}
 #'
 #' @examples
-#' \dontrun{
 #' data(cross_1year)
 #'
-#' # Model fit
+#' \dontrun{
+#' # Fitting the model
 #' mod0 <- nnet::multinom(employment_sit ~ finalgrade + irregularity + hsscore,
 #'   cross_1year)
 #' mod0
@@ -171,47 +219,69 @@ is_simplified_field3logit <- function(x) {
 #' gg3logit(field0) + stat_field3logit()
 #' }
 #'
+#' # Fitting the model
+#' mod1 <- nnet::multinom(employment_sit ~ ., data = cross_1year)
+#'
+#' # List passed to argument "delta" for generating "multifield3logit" objects
+#' refpoint <- list(c(0.7, 0.15, 0.15))
+#' depo <- list(
+#'   list(delta = 'durationShort',  label = 'Short duration'),
+#'   list(delta = 'durationLong',   label = 'Long duration'),
+#'   list(delta = 'finalgradeHigh', label = 'High final grade'),
+#'   list(delta = 'finalgradeLow',  label = 'Low final grade')
+#' )
+#' mfields <- field3logit(mod1, delta = depo, p0 = refpoint, narrows = 1)
+#' mfields
+#'
 #' @export
 field3logit <- function(model, delta, label = '<empty>', p0 = NULL,
-  alpha = NULL, vcov = NULL, ncurves = 8, narrows = Inf, edge = 0.01,
+  alpha = NULL, vcov = NULL, nstreams = 8, narrows = Inf, edge = 0.01,
   conf = NA, npoints = 100) {
 
-  # Read input
-  modB <- read_model(model, 'logit', alpha, vcov)
-  vdelta <- get_vdelta(delta, modB)
-  DeltaB <- as.numeric(crossprod(vdelta, modB$B))
-
-  # Compute the starting points of the curves
-  if (is.null(p0)) {
-    modB$DeltaB2pc(DeltaB, ncurves, edge) %>%
-      pc2p0(DeltaB, edge, modB[c('XB2P','P2XB')]) -> p0
+  # Check argument "delta"
+  if (is.list(delta)) {
+  	field3logit_list(
+  	  model, delta, label, p0, alpha, vcov,
+  	  nstreams, narrows, edge, conf, npoints
+    ) -> out
   } else {
-    p0 <- list(pp = p0)
-    p0$status <- ifelse(all(DeltaB == 0), 'p', 'p0')
-  }
+    # Read input
+    modB <- read_model(model, 'logit', alpha, vcov)
+    vdelta <- get_vdelta(delta, modB)
+    DeltaB <- as.numeric(crossprod(vdelta, modB$B))
 
-  # Compute the arrows
-  if (p0$status == 'p') {
-  	lapply(p0$pp, function(x) {
-  	  list(A1 = list(from = x, to = rep(NA, 3)))
-  	}) -> out
-  } else {
-    out <- lapply(p0$pp, gen_path, DeltaB = DeltaB,
-      edge = edge, nmax = narrows, flink = modB[c('XB2P','P2XB')])
-  }
+    # Compute the starting points of the curves
+    if (is.null(p0)) {
+      modB$DeltaB2pc(DeltaB, nstreams, edge) %>%
+        pc2p0(DeltaB, edge, modB[c('XB2P','P2XB')]) -> p0
+    } else {
+      p0 <- list(pp = p0)
+      p0$status <- ifelse(all(DeltaB == 0), 'p', 'p0')
+    }
 
-  # Create field3logit object
-  names(out) %<>% paste0('C', 1:length(out), .)
-  out <- list(B = modB$B, alpha = modB$alpha, delta = delta,
-    vdelta = vdelta, lab = modB$lab, readfrom = modB$readfrom,
-    effects = out, label = label, vcovB = modB$vcovB,
-    ordinal = modB$ordinal, conf = conf
-  )
-  class(out) <- 'field3logit'
+    # Compute the arrows
+    if (p0$status == 'p') {
+    	  lapply(p0$pp, function(x) {
+  	    list(A1 = list(from = x, to = rep(NA, 3)))
+  	  }) -> out
+    } else {
+      out <- lapply(p0$pp, gen_path, DeltaB = DeltaB,
+        edge = edge, nmax = narrows, flink = modB[c('XB2P','P2XB')])
+    }
+
+    # Create field3logit object
+    names(out) %<>% paste0('C', 1:length(out), .)
+    out <- list(B = modB$B, alpha = modB$alpha, delta = delta,
+      vdelta = vdelta, lab = modB$lab, readfrom = modB$readfrom,
+      effects = out, label = label, vcovB = modB$vcovB,
+      ordinal = modB$ordinal, conf = conf
+    )
+    class(out) <- 'field3logit'
   
-  # Compute the confidence regions
-  if (!is.null(out$vcov) & !is.na(conf)) {
-  	out %<>% add_confregions(conf, npoints)
+    # Compute the confidence regions
+    if (!is.null(out$vcov) & !is.na(conf)) {
+  	  out %<>% add_confregions(conf, npoints)
+    }
   }
   
   # Output
@@ -244,7 +314,7 @@ print.field3logit <- function(x, ...) {
   }
   
   cat('Model has been read from :', x$readfrom, '\n')
-  cat('Number of curves         :', length(x$effects), '\n')
+  cat('Number of stream lines   :', length(x$effects), '\n')
   cat('Number of arrows         :', na, '\n')
   cat('Covariance matrix        :', vcovB, '\n')
   cat('Confidence regions       :', conf, '\n')
@@ -324,8 +394,17 @@ as.data.frame.field3logit <- function(x, ..., wide = TRUE) {
 
 #' @rdname field3logit
 #' @export
-fortify.field3logit <- function(model, data, ...) {
-  as_tibble.field3logit(model, ...) %>%
+fortify.field3logit <- function(model, data, ..., wide = TRUE) {
+  as_tibble.field3logit(model, ..., wide = wide) %>%
+    return
+}
+
+
+
+#' @rdname field3logit
+#' @export
+tidy.field3logit <- function(x, ..., wide = TRUE) {
+  as_tibble.field3logit(x, ..., wide = wide) %>%
     return
 }
 
@@ -347,4 +426,20 @@ vcov.field3logit <- function(object, ...) {
 
 
 
+#' @rdname field3logit
+#' @export
+labels.field3logit <- function(object, ...) {
+  return(object$label)
+}
+
+
+
+#' @rdname field3logit
+#' @export
+`labels<-.field3logit` <- function(x, value) {
+  x$label <- as.character(value)[1]
+  return(x)
+}
+
+
 
